@@ -9,9 +9,9 @@ __all__ = [
 
 __title__ = "recliner"
 __summary__ = ""
-__uri__ = "https://github.com/crateio/recliner/"
+__uri__ = "https://github.com/dstufft/recliner/"
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 
 __author__ = "Donald Stufft"
 __email__ = "donald.stufft@gmail.com"
